import getpass
import os
import json
import requests
import uuid

class GithubException(Exception):
    def __init__(self, value):
        self.value = value
    def __str__(self):
        return repr(self.value)

class Github:

    def get_credential(self,scopes,save_path):
        if os.path.isfile(save_path):
            with open(save_path) as f:
                return json.loads(f.read())

        user = auth()

        hash_str = uuid.uuid1()
        payload = {"scopes": scopes, "note": "use gist_it #%s" % hash_str}

        response = requests.post("https://api.github.com/authorizations", data=json.dumps(payload), auth=(user[0], user[1]))
        if response.status_code is not 201:
            raise GithubException("github oauth api error: %s" % response.text)

        with open(save_path, "w") as f:
            f.write(response.text)
        return json.loads(response.text)

def auth():
    user_name = raw_input('user_name : ')
    password = getpass.getpass('password  : ')
    if not user_name or not password:
        raise GithubException("username or password is not found")

    return user_name, password

if __name__ == '__main__':
    pass



# -*- coding: utf-8 -*-
"""Gist_it can send gist

ex)
gist_it FILE_NAME
cat FILE_NAME | gist_it

oauth credential is saved $HOME/.gist_it_credential
if occure error. rm $HOME/.gist_it_credential

Usage:	gist_it -h | --help
	gist_it init [--credential=<credential>]
	gist_it [-a] [-p] [--credential=<credential>] [--title=<title>] <file>
	gist_it [-a] [-p] [--credential=<credential>] [--title=<title>] 

Options:
	init		if use auth user. (only first time)
	file		If omitted, use stdin.
	-h --help	show this help message and exit
	-a		auth user (if use stdin. run "gist_it init")
	-c		github oauth credential path (use cache)
	-p		add public option
	--title=<title>	add title [default: "None"].
	--credential=<credential>	set credential path

"""

from docopt import docopt
import sys
import os
from gist import Gist
from github import Github

class GistitException(Exception):
    def __init__(self, value):
        self.value = value
    def __str__(self):
        return repr(self.value)

def main():
    args = docopt(__doc__)

    credential = args["--credential"]
    if not credential or not os.path.isfile(credential):
        credential = os.environ['HOME'] + "/.gist_it_credential"

    if args["init"]:
        Github().get_credential(Gist.scope, credential)
        print "save credential to %s" % credential
        return

    is_public = False
    if args["-p"]:
        is_public = True

    is_auth = False
    if args["-a"]:
        is_auth = True

    text = ""
    file_name = args["<file>"]
    if file_name and os.path.isfile(file_name):
        text = open(file_name).read()
    elif not sys.stdin.isatty():
        text = sys.stdin.read()
    else:
        print __doc__
        sys.exit(1)

    if args["--title"]:
        file_name = args["--title"]

    response = Gist(credential).create(file_name,text,"",is_public,is_auth)
    if response and "html_url" in response:
        print response["html_url"]
    else:
        raise GistitException("gist response error")
        

if __name__ == '__main__':
    try:
        main()
    except Exception, e:
        print e
        sys.exit(1)



import os
import requests
import json
from github import Github

class GistException(Exception):
    def __init__(self, value):
        self.value = value
    def __str__(self):
        return repr(self.value)

class Gist:

    scope = ["gist"]

    def __init__(self,credential_path):
        self.credential_path = credential_path

    def create(self,file_name,content,description="",public=False,is_auth=False):
        headers = {}
        if is_auth:
            credential = Github().get_credential(Gist.scope, self.credential_path)
            if not credential:
                raise GistException("Github oauth error")

            headers = {'Authorization': 'token %s' % str(credential["token"])}

        payload = {"description": description, "public": public, "files": { file_name: {"content": content}}}
        response = requests.post("https://api.github.com/gists", data=json.dumps(payload), headers=headers)
        if response.status_code is not 201:
            raise GistException("gist api error: %s" % response.text)
        return json.loads(response.text)

if __name__ == '__main__':
    pass



from setuptools import setup, find_packages

install_requires=['requests', 'docopt']

try:
    import json
except ImportError:
    install_requires.append('simplejson')

setup(
    name='gist_it',
    version='1.0.5',
    license='MIT',
    description='Gist_it can send gist',
    author='se s',
    url='https://github.com/gk024kfd/gist_it',
    author_email='3f2j3g02jgw@gmail.com',
    packages=find_packages(),
    install_requires=install_requires,
    entry_points={
        'console_scripts':
            'gist_it = main.main:main'
    },
    zip_safe=False,
    classifiers=[
          'Environment :: Console',
          'Intended Audience :: Developers',
          'Operating System :: MacOS :: MacOS X',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2.7',
    ],
)
